﻿using System;
using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace Wpf_TextStyleSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.Meter;
            wpfMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.SimpleColors.LightBlue);

            TextStyle textStyle = GetTextStyleByUI("STREETNAME", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColors.ControlText));


            //ShapeFileFeatureSource.BuildIndexFile(@"../../data/Transportation.shp");
            ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer(@"../../data/Transportation.shp");
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = textStyle;
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.LocalRoad1;
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            LayerOverlay layerOverlay = new LayerOverlay();

            layerOverlay.TileWidth = 768;
            layerOverlay.TileHeight = 768;

            layerOverlay.Layers.Add(shapeFileFeatureLayer);

            InMemoryFeatureLayer inMemoryFeatureLayer = new InMemoryFeatureLayer();
            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Highway1;
            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
         
            layerOverlay.Layers.Add("inMemoryFeatureLayer", inMemoryFeatureLayer);

            wpfMap1.Overlays.Add(layerOverlay);

            wpfMap1.CurrentExtent = new RectangleShape(1134532.55785097, 1918778.82749093, 1137264.84367716, 1917183.20851646);
        }

        private void wpfMap1_MapClick(object sender, MapClickWpfMapEventArgs e)
        {
            var featureLayer = (((LayerOverlay)wpfMap1.Overlays[0]).Layers[0]) as ShapeFileFeatureLayer;
            featureLayer.Open();
            var features = featureLayer.QueryTools.GetFeaturesNearestTo(e.WorldLocation, wpfMap1.MapUnit, 1, ReturningColumnsType.AllColumns);
            var inMemoryFeatureLayer = (((LayerOverlay)wpfMap1.Overlays[0]).Layers[1]) as InMemoryFeatureLayer;
            inMemoryFeatureLayer.InternalFeatures.Clear();
            foreach (var feature in features)
            {
                inMemoryFeatureLayer.InternalFeatures.Add(feature);
            }
            wpfMap1.Refresh();
        }


        private TextStyle GetTextStyleByUI(string textColumnName, GeoFont textFont, GeoSolidBrush textSolidBrush)
        {
            TextStyle textStyle = new TextStyle(textColumnName, textFont, textSolidBrush);

            textStyle.GridSize = int.Parse(textBoxGridSize.Text);

            textStyle.SuppressPartialLabels = (bool)radioButtonSuppressPartialLabelsTrue.IsChecked ? true : false;

            textStyle.OverlappingRule = (bool)radioButtonLabelOverlappingRuleNo.IsChecked ? LabelOverlappingRule.NoOverlapping : LabelOverlappingRule.AllowOverlapping;


            if (radioButtonLabelDuplicateRuleOne.IsChecked == true)
            {
                textStyle.DuplicateRule = LabelDuplicateRule.OneDuplicateLabelPerQuadrant;
            }
            else if (radioButtonLabelDuplicateRuleNo.IsChecked == true)
            {
                textStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            }
            else
            {
                textStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
            }

            textStyle.LabelAllLineParts = (bool)radioButtonLabelAllLinePartsTrue.IsChecked ? true : false;

            if (radioButtonDrawingLevelLabel.IsChecked == true)
            {
                textStyle.DrawingLevel = DrawingLevel.LabelLevel;
            }
            else
            {
                if (radioButtonDrawingLevelOne.IsChecked == true)
                {
                    textStyle.DrawingLevel = DrawingLevel.LevelOne;
                }
                else if (radioButtonDrawingLevelTwo.IsChecked == true)
                {
                    textStyle.DrawingLevel = DrawingLevel.LevelTwo;
                }
                else if (radioButtonDrawingLevelThree.IsChecked == true)
                {
                    textStyle.DrawingLevel = DrawingLevel.LevelThree;
                }
                else if (radioButtonDrawingLevelFour.IsChecked == true)
                {
                    textStyle.DrawingLevel = DrawingLevel.LevelFour;
                }
            }

            if (radioButtonSplineTypeDefault.IsChecked == true)
            {
                textStyle.SplineType = SplineType.Default;
            }
            else if (radioButtonSplineTypeNone.IsChecked == true)
            {
                textStyle.SplineType = SplineType.None;
            }
            else if (radioButtonSplineTypeStandard.IsChecked == true)
            {
                textStyle.SplineType = SplineType.StandardSplining;
            }
            else if (radioButtonSplineTypeForce.IsChecked == true)
            {
                textStyle.SplineType = SplineType.ForceSplining;
            }

            textStyle.TextLineSegmentRatio = double.Parse(textBoxTextLineSegmentRatio.Text);

            textStyle.FittingLineInScreen = (bool)radioButtonFittingLineInScreenTrue.IsChecked ? true : false;

            textStyle.MaxNudgingInPixel = int.Parse(textBoxMaxNudgingInPixel.Text);

            textStyle.NudgingIntervalInPixel = float.Parse(textBoxNudgingIntervalInPixel.Text);

            textStyle.ForceHorizontalLabelForLine = (bool)radioButtonForceHorizontalLabelForLineTrue.IsChecked ? true : false;

            return textStyle;
        }


        private void RefreshMap()
        {
            if (wpfMap1.Overlays.Count > 0)
            {
                TextStyle textStyle = GetTextStyleByUI("STREETNAME", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColors.ControlText));
                var shapeFileFeatureLayer = (((LayerOverlay)wpfMap1.Overlays[0]).Layers[0]) as ShapeFileFeatureLayer;
                shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = textStyle;
                shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.LocalRoad1;
                shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                wpfMap1.Refresh();
            }
        }


        #region TextStyle Properties 

        private void buttonReGridSize_Click(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonSuppressPartialLabelsTrue_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButton1_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonLabelOverlappingRuleNo_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButton3_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonLabelDuplicateRuleOne_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonLabelDuplicateRuleNo_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonLabelDuplicateRuleUnlimited_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonLabelAllLinePartsTrue_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButton8_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonDrawingLevelOne_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonDrawingLevelTwo_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonDrawingLevelThree_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonDrawingLevelFour_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonDrawingLevelLabel_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonSplineTypeDefault_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonSplineTypeNone_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonSplineTypeStandard_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonSplineTypeForce_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void buttonReTextLineSegmentRatio_Click(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonFittingLineInScreenTrue_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButton19_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void buttonReMaxNudgingInPixel_Click(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void buttonReNudgingIntervalInPixel_Click(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButtonForceHorizontalLabelForLineTrue_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        private void radioButton21_Checked(object sender, RoutedEventArgs e)
        {
            RefreshMap();
        }

        #endregion


    }
}
